@@ -104,25 +104,6 @@ def get_aircraft_image(aircraft_hex):
     return image
 
 
-def get_aircraft(base_url, filter_aircraft = True):
-    """
-    Get the aircraft messages and returns as list
-    """
-    receiver_url = f'{base_url}/data/aircraft.json'
-
-    response = requests.get(receiver_url)
-    json_obj = json.loads(response.content)
-    result = json_obj
-
-    if (filter_aircraft):
-        result = [
-            d for d in json_obj['aircraft']
-            if "lat" in d and "lon" in d and d["lat"] is not None and d["lon"] is not None
-        ]
-
-    return result
-
-
 def get_hex_db_flight(icao_24):
     """
     Get values from HexDB
@@ -143,3 +124,22 @@ def get_adsb_db_flight(icao_24):
     adsb_db_obj = json.loads(adsb_db_result.content)
 
     return adsb_db_obj
+
+
+def get_aircraft(base_url, filter_aircraft = True):
+    """
+    Get the aircraft messages and returns as list
+    """
+    receiver_url = f'{base_url}/data/aircraft.json'
+
+    response = requests_utils.call_url(receiver_url)
+    json_obj = json.loads(response.content)
+    result = json_obj
+
+    if (filter_aircraft):
+        result = [
+            d for d in json_obj['aircraft']
+            if "lat" in d and "lon" in d and d["lat"] is not None and d["lon"] is not None
+        ]
+
+    return result
