@@ -13,11 +13,11 @@ def call_url(url: str, timeout: int = 5) -> requests.Response:
             or `None` if an error occurs.
     """
     try:
-        print("{url}: attempting request...")
+        print(f"{url}: attempting request...")
         response = requests.get(url=url, timeout=timeout)
         response.raise_for_status()
     except requests.exceptions.Timeout:
-        print("{url}: timeout error occurred.")
+        print(f"{url}: timeout error occurred.")
     except requests.exceptions.HTTPError as err:
         print(f"{url}: HTTP error occurred: {err}")
     except requests.exceptions.RequestException as err:
